@@ -1,22 +1,38 @@
 import logging
+import warnings
 from json import dumps
-from typing import Union, List, Optional
+from typing import List
+from typing import Optional
+from typing import TYPE_CHECKING
+from typing import Union
 
 import aiohttp
 import discord
-# noinspection PyPep8Naming
-from discord import Client as C, AutoShardedClient as AC
-# noinspection PyPep8Naming
-from discord.ext.commands import Bot as B, AutoShardedBot as AB
 from discord.ext.tasks import loop
 
-from .errors import ToppyError, Forbidden, TopGGServerError, Ratelimited, NotFound
-from .models import Bot, SimpleUser, BotStats, User, BotSearchResults
+from .errors import Forbidden
+from .errors import NotFound
+from .errors import Ratelimited
+from .errors import TopGGServerError
+from .errors import ToppyError
+from .models import Bot
+from .models import BotSearchResults
+from .models import BotStats
+from .models import SimpleUser
+from .models import User
 from .ratelimiter import routes
 
-__version__ = "1.3.0a4"
-__api_version__ = "v0"
-_base_ = "https://top.gg/api"
+# noinspection PyPep8Naming
+
+if TYPE_CHECKING:
+    from discord import AutoShardedClient as _AutoClient
+    from discord import Client as _Client
+    from discord.ext.commands import AutoShardedBot as _AutoBot
+    from discord.ext.commands import Bot as _Bot
+
+    bot_types = Union[_Client, _AutoClient, _Bot, _AutoBot]
+
+__version__ = "1.3.2"
 logger = logging.getLogger(__name__)
 
 
@@ -27,8 +43,10 @@ class TopGG:
     This class handles everything for the top.gg API, APART FROM voting webhooks - Those are handled by the server
     class.
     """
+    __api_version__ = "v0"
+    _base_ = "https://top.gg/api"
 
-    def __init__(self, bot: Union[C, B, AC, AB], *, token: str, autopost: bool = True):
+    def __init__(self, bot: "bot_types", *, token: str, autopost: bool = True):
         r"""
         Initialises an instance of the top.gg client. Please don't call this multiple times, it WILL break stuff.
 
@@ -46,10 +64,6 @@ class TopGG:
         self.ratelimit_persistence = True
         # noinspection PyTypeChecker
         self._session: Optional[aiohttp.ClientSession] = None
-        # noinspection PyTypeChecker
-        if aiosqlite is not None:
-            self._db: Optional[aiosqlite.Connection] = None
-
         if autopost:
             logger.debug("Starting autopost task.")
             self.autopost.start()
@@ -59,6 +73,15 @@ class TopGG:
         self.has_upvoted = self.upvote_check
         self.get_user_vote = self.upvote_check
 
+    def _change_api_version(self, v: int):
+        # You shouldn't use this unless v1 is released, and you MUST use it before the package catches up.
+        # If you change the API version then there is no guarantee that literally anything will work.
+        warnings.warn(UserWarning("You changed the API version. functionality is not a guarantee."))
+        # I actually have no idea how they'll handle the API version change, so we're just gonna
+        # append the version string
+        self.__api_version__ = "v" + str(v)
+        self._base_ += self.__api_version__
+
     def __del__(self):
         r"""Lower-level garbage collection function fired when the variable is discarded, performs cleanup."""
         logger.debug(f"{id(self)} __del__ called - Stopping autopost task")
@@ -100,7 +123,7 @@ class TopGG:
         if not self.session:
             self._session = aiohttp.ClientSession(
                 headers={
-                    "User-Agent": f"top.py (version {__version__}, https://github.com/dragdev-studios/top.py)",
+                    "User-Agent": f"top.py (version {__version__}, https://github.com/EEKIM10/top.py)",
                     "Authorization": self.token,
                     "Content-Type": "application/json",
                     "Accept": "application/json",
@@ -141,7 +164,7 @@ class TopGG:
             kwargs["data"] = dumps(kwargs["data"])
 
         expected_codes = kwargs.pop("expected_codes", [200])
-        url = _base_ + uri
+        url = self._base_ + uri
         await self._wf_s()
 
         logger.info('Sending "{} {}"...'.format(method, url))
@@ -157,7 +180,7 @@ class TopGG:
                 routes["*"].add_hit()
 
             if "application/json" not in response.headers.get("content-type", "none").lower():
-                logger.warning(f"Got unexpected mime type {response.headers['Content-Type']} from top.gg.")
+                logger.warning(f"Got unexpected content type {response.headers['Content-Type']!r} from top.gg.")
                 raise ToppyError("Unexpected response from server.")
             if response.status in [403, 401]:
                 raise Forbidden()
